@@ -11,7 +11,7 @@
  *                                                                  *
  ********************************************************************
 
- last mod: $Id: buffer.c 16870 2010-02-04 14:15:42Z xiphmont $
+ last mod: $Id$
 
  ********************************************************************/
 
@@ -94,6 +94,7 @@ void buffer_thread_init (buf_t *buf)
 void buffer_thread_cleanup (void *arg)
 {
   buf_t *buf = (buf_t *)arg;
+  (void)buf;
 
   DEBUG("Enter buffer_thread_cleanup");
 }
@@ -209,12 +210,22 @@ void *buffer_thread_func (void *arg)
      never be unset. */
   while ( !(buf->eos && buf->curfill == 0) && !buf->abort_write) {
 
-    if (buf->cancel_flag || sig_request.cancel)
+    LOCK_MUTEX (buf->mutex);
+
+    DEBUG("Check for cancelation");
+    if (buf->cancel_flag || sig_request.cancel) {
+      /* signal empty buffer space, so the main
+         thread can wake up to die in peace */
+      DEBUG("Abort: Wake up the writer thread");
+      COND_SIGNAL(buf->write_cond);
+
+      /* abort this thread, too */
+      UNLOCK_MUTEX(buf->mutex);
       break;
+    }
 
     DEBUG("Check for something to play");
     /* Block until we can play something */
-    LOCK_MUTEX (buf->mutex);
     if (buf->prebuffering || 
 	buf->paused || 
 	(buf->curfill < buf->audio_chunk_size && !buf->eos)) {
@@ -223,13 +234,22 @@ void *buffer_thread_func (void *arg)
       COND_WAIT(buf->playback_cond, buf->mutex);
     }
 
+    DEBUG("Check for cancelation");
+    if (buf->cancel_flag || sig_request.cancel) {
+      /* signal empty buffer space, so the main
+         thread can wake up to die in peace */
+      DEBUG("Abort: Wake up the writer thread");
+      COND_SIGNAL(buf->write_cond);
+
+      /* abort this thread, too */
+      UNLOCK_MUTEX(buf->mutex);
+      break;
+    }
+
     DEBUG("Ready to play");
 
     UNLOCK_MUTEX(buf->mutex);
 
-    if (buf->cancel_flag || sig_request.cancel)
-      break;
-
     /* Don't need to lock buffer while running actions since position
        won't change.  We clear out any actions before we compute the
        dequeue size so we don't consider actions that need to
@@ -287,7 +307,7 @@ void *buffer_thread_func (void *arg)
 }
 
 
-int submit_data_chunk (buf_t *buf, char *data, size_t size)
+int submit_data_chunk (buf_t *buf, unsigned char *data, size_t size)
 {
   long   buf_write_pos; /* offset of first available write location */
   size_t write_size;
@@ -525,7 +545,7 @@ void buffer_thread_kill (buf_t *buf)
 
 /* --- Data buffering functions --- */
 
-int buffer_submit_data (buf_t *buf, char *data, long nbytes) {
+int buffer_submit_data (buf_t *buf, unsigned char *data, long nbytes) {
   return submit_data_chunk (buf, data, nbytes);
 }
 
@@ -756,7 +776,7 @@ void buffer_wait_for_empty (buf_t *buf)
   pthread_cleanup_push(buffer_mutex_unlock, buf);
 
   LOCK_MUTEX(buf->mutex);
-  while (!empty && !buf->abort_write) {
+  while (!empty && !buf->abort_write && !buf->cancel_flag && !sig_request.cancel) {
 
     if (buf->curfill > 0) {
       DEBUG1("Buffer curfill = %ld, going back to sleep.", buf->curfill);
