@@ -11,10 +11,14 @@
  *                                                                  *
  ********************************************************************
 
- last mod: $Id: speex_format.c,v 1.3 2003/06/24 02:22:33 giles Exp $
+ last mod: $Id$
 
  ********************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -43,7 +47,7 @@ typedef struct speex_private_t {
   ogg_packet op;
   ogg_stream_state os;
   SpeexBits bits;
-  SpeexStereoState stereo;
+  SpeexStereoState *stereo;
   SpeexHeader *header;
   void *st;
 
@@ -54,7 +58,7 @@ typedef struct speex_private_t {
 		    elements */ 
   int output_start;
   int output_left;
-  
+
   int frames_per_packet;
   int frame_size;
   int vbr;
@@ -99,7 +103,7 @@ int speex_can_decode (data_source_t *source)
   int len;
 
   len = source->transport->peek(source, buf, sizeof(char), 36);
-  
+
   if (len >= 32 && memcmp(buf, "OggS", 4) == 0
       && memcmp(buf+28, "Speex   ", 8) == 0) /* 3 trailing spaces */
     return 1;
@@ -138,13 +142,14 @@ decoder_t* speex_init (data_source_t *source, ogg123_options_t *ogg123_opts,
     private->comment_packet = NULL;
     private->comment_packet_len = 0;
     private->header = NULL;
+    private->stereo = speex_stereo_state_init();
 
     private->stats.total_time = 0.0;
     private->stats.current_time = 0.0;
     private->stats.instant_bitrate = 0;
     private->stats.avg_bitrate = 0;
   } else {
-    fprintf(stderr, _("Error: Out of memory.\n"));
+    fprintf(stderr, _("ERROR: Out of memory.\n"));
     exit(1);
   }
 
@@ -177,7 +182,7 @@ int speex_read (decoder_t *decoder, void *ptr, int nbytes, int *eos,
   if (priv->bos) {
 
     ret = read_speex_header(decoder);
-    
+
     if (!ret) {
       *eos = 1;
       return 0; /* Bail out! */
@@ -196,7 +201,7 @@ int speex_read (decoder_t *decoder, void *ptr, int nbytes, int *eos,
   while (nbytes) {
     char *data;
     int i, j, nb_read;
-    
+
     /* First see if there is anything left in the output buffer and 
        empty it out */
     if (priv->output_left > 0) {
@@ -205,7 +210,7 @@ int speex_read (decoder_t *decoder, void *ptr, int nbytes, int *eos,
       to_copy *= audio_fmt->channels;
 
       to_copy = priv->output_left < to_copy ? priv->output_left : to_copy;
-      
+
       /* Integerify it! */
       for (i = 0; i < to_copy; i++)
 	out[i]=(ogg_int16_t)priv->output[i+priv->output_start];
@@ -213,24 +218,24 @@ int speex_read (decoder_t *decoder, void *ptr, int nbytes, int *eos,
       out += to_copy;
       priv->output_start += to_copy;
       priv->output_left -= to_copy;
-     
+
       priv->currentsample += to_copy / audio_fmt->channels;
 
-      nbytes -= to_copy * 2;      
+      nbytes -= to_copy * 2;
     } else if (ogg_stream_packetout(&priv->os, &priv->op) == 1) {
       float *temp_output = priv->output;
       /* Decode some more samples */
-            
+
       /*Copy Ogg packet to Speex bitstream*/
       speex_bits_read_from(&priv->bits, (char*)priv->op.packet, 
 			   priv->op.bytes);
-      
+
       for (j = 0;j < priv->frames_per_packet; j++) {
 	/*Decode frame*/
 	speex_decode(priv->st, &priv->bits, temp_output);
 
 	if (audio_fmt->channels==2)
-	  speex_decode_stereo(temp_output, priv->frame_size, &priv->stereo);
+	  speex_decode_stereo(temp_output, priv->frame_size, priv->stereo);
 	
 	priv->samples_decoded += priv->frame_size;
 
@@ -241,7 +246,7 @@ int speex_read (decoder_t *decoder, void *ptr, int nbytes, int *eos,
 	  else if (temp_output[i]<-32000.0)
 	    temp_output[i]=-32000.0;
 	}
-	
+
 	temp_output += priv->frame_size * audio_fmt->channels;
       }
 
@@ -253,7 +258,7 @@ int speex_read (decoder_t *decoder, void *ptr, int nbytes, int *eos,
       ogg_stream_pagein(&priv->os, &priv->og);
     } else if (!priv->eof) {
       /* Finally, pull in some more data and try again on the next pass */
-      
+
       /*Get the ogg buffer for writing*/
       data = ogg_sync_buffer(&priv->oy, 200);
       /*Read bitstream from input file*/
@@ -270,7 +275,7 @@ int speex_read (decoder_t *decoder, void *ptr, int nbytes, int *eos,
       break;
     }
   }
-  
+
   return bytes_requested - nbytes;
 }
 
@@ -279,7 +284,9 @@ int speex_seek (decoder_t *decoder, double offset, int whence)
 {
   speex_private_t *priv = decoder->private;
 
-    return 0;
+  (void)priv;
+
+  return 0;
 }
 
 
@@ -289,7 +296,6 @@ decoder_stats_t *speex_statistics (decoder_t *decoder)
 {
   speex_private_t *priv = decoder->private;
   long instant_bitrate;
-  long avg_bitrate;
 
   priv->stats.total_time = (double) priv->totalsamples /
     (double) decoder->actual_fmt.rate;
@@ -324,6 +330,7 @@ void speex_cleanup (decoder_t *decoder)
 {
   speex_private_t *priv = decoder->private;
 
+  speex_stereo_state_destroy(priv->stereo);
   free(priv->comment_packet);
   free(priv->output);
   free(decoder->private);
@@ -405,9 +412,9 @@ void print_speex_comments(char *comments, int length,
 
   strncpy(temp, c, len);
   temp[len] = '\0';
-		
+
   cb->printf_metadata(callback_arg, 3, _("Encoded by: %s"), temp);
-  
+
 
   /* Parse out user comments */
 
@@ -436,7 +443,7 @@ void print_speex_comments(char *comments, int length,
       free(temp);
       return;
     }
-    
+
     if (temp_len < len + 1) {
       temp_len = len + 1;
       temp = realloc(temp, sizeof(char) * temp_len);
@@ -445,7 +452,7 @@ void print_speex_comments(char *comments, int length,
 
     strncpy(temp, c, len);
     temp[len] = '\0';
-    
+
     print_vorbis_comment(temp, cb, callback_arg);
 
     c += len;
@@ -461,17 +468,17 @@ void *process_header(ogg_packet *op, int *frame_size,
 		     void *callback_arg)
 {
    void *st;
-   SpeexMode *mode;
+   const SpeexMode *mode;
    int modeID;
    SpeexCallback callback;
    int enhance = ENHANCE_AUDIO;
-   
+
    *header = speex_packet_to_header((char*)op->packet, op->bytes);
    if (!*header) {
            cb->printf_error(callback_arg, ERROR, _("Cannot read header"));
      return NULL;
    }
-   if ((*header)->mode >= SPEEX_NB_MODES) {
+   if ((*header)->mode >= SPEEX_NB_MODES || (*header)->mode < 0) {
      cb->printf_error(callback_arg, ERROR, 
 		      _("Mode number %d does not (any longer) exist in this version"),
 	      (*header)->mode);
@@ -480,7 +487,7 @@ void *process_header(ogg_packet *op, int *frame_size,
 
    modeID = (*header)->mode;
    mode = speex_mode_list[modeID];
-   
+
    if (mode->bitstream_version < (*header)->mode_bitstream_version) {
      cb->printf_error(callback_arg, ERROR, _("The file was encoded with a newer version of Speex.\n You need to upgrade in order to play it.\n"));
      return NULL;
@@ -489,11 +496,11 @@ void *process_header(ogg_packet *op, int *frame_size,
      cb->printf_error(callback_arg, ERROR, _("The file was encoded with an older version of Speex.\nYou would need to downgrade the version in order to play it."));
      return NULL;
    }
-   
+
    st = speex_decoder_init(mode);
    speex_decoder_ctl(st, SPEEX_SET_ENH, &enhance);
    speex_decoder_ctl(st, SPEEX_GET_FRAME_SIZE, frame_size);
-   
+
    callback.callback_id = SPEEX_INBAND_STEREO;
    callback.func = speex_std_stereo_request_handler;
    callback.data = stereo;
@@ -517,11 +524,11 @@ int read_speex_header (decoder_t *decoder)
   while (packet_count < 2) {
     /*Get the ogg buffer for writing*/
     data = ogg_sync_buffer(&priv->oy, 200);
-    
+
     /*Read bitstream from input file*/
     nb_read = trans->read(decoder->source, data, sizeof(char), 200);
     ogg_sync_wrote(&priv->oy, nb_read);
-    
+
     /*Loop for all complete pages we got (most likely only one)*/
     while (ogg_sync_pageout(&priv->oy, &priv->og)==1) {
 
@@ -529,7 +536,7 @@ int read_speex_header (decoder_t *decoder)
 	ogg_stream_init(&priv->os, ogg_page_serialno(&priv->og));
 	stream_init = 1;
       }
-    
+
       /*Add page to the bitstream*/
       ogg_stream_pagein(&priv->os, &priv->og);
 
@@ -540,7 +547,7 @@ int read_speex_header (decoder_t *decoder)
 	  priv->st = process_header(&priv->op, 
 				    &priv->frame_size,
 				    &priv->header,
-				    &priv->stereo,
+				    priv->stereo,
 				    decoder->callbacks,
 				    decoder->callback_arg);
 
@@ -554,7 +561,19 @@ int read_speex_header (decoder_t *decoder)
 
 	  if (!priv->frames_per_packet)
 	    priv->frames_per_packet=1;
-	
+
+      switch(decoder->actual_fmt.channels) {
+      case 1:
+        decoder->actual_fmt.matrix="M";
+        break;
+      case 2:
+        decoder->actual_fmt.matrix="L,R";
+        break;
+      default:
+        decoder->actual_fmt.matrix=NULL;
+        break;
+      }
+
 
 	  priv->output = calloc(priv->frame_size * 
 				decoder->actual_fmt.channels * 
