@@ -11,7 +11,7 @@
  *                                                                  *
  ********************************************************************
 
- last mod: $Id: transport.c,v 1.4 2002/05/05 03:45:04 segher Exp $
+ last mod: $Id$
 
  ********************************************************************/
 
@@ -30,7 +30,7 @@ extern transport_t file_transport;
 extern transport_t http_transport;
 #endif
 
-transport_t *transports[] = {
+static const transport_t *transports[] = {
 #ifdef HAVE_CURL
   &http_transport,
 #endif
@@ -39,7 +39,7 @@ transport_t *transports[] = {
 };
 
 
-transport_t *get_transport_by_name (char *name)
+const transport_t *get_transport_by_name (const char *name)
 {
   int i = 0;
 
@@ -50,7 +50,7 @@ transport_t *get_transport_by_name (char *name)
 }
 
 
-transport_t *select_transport (char *source)
+const transport_t *select_transport (const char *source)
 {
   int i = 0;
 
@@ -68,7 +68,7 @@ data_source_stats_t *malloc_data_source_stats (data_source_stats_t *to_copy)
   new_stats = malloc(sizeof(data_source_stats_t));
 
   if (new_stats == NULL) {
-    fprintf(stderr, _("Error: Could not allocate memory in malloc_data_source_stats()\n"));
+    fprintf(stderr, _("ERROR: Could not allocate memory in malloc_data_source_stats()\n"));
     exit(1);
   }
 
