@@ -7,9 +7,9 @@
 typedef void TIMER;
 typedef long (*audio_read_func)(void *src, float **buffer, int samples);
 typedef void (*progress_func)(char *fn, long totalsamples, 
-		long samples, double time);
+        long samples, double time);
 typedef void (*enc_end_func)(char *fn, double time, int rate, 
-		long samples, long bytes);
+        long samples, long bytes);
 typedef void (*enc_start_func)(char *fn, char *outfn, int bitrate, 
         float quality, int qset, int managed, int min_br, int max_br);
 typedef void (*error_func)(char *errormessage);
@@ -18,7 +18,7 @@ typedef void (*error_func)(char *errormessage);
 void *timer_start(void);
 double timer_time(void *);
 void timer_clear(void *);
-int create_directories(char *);
+int create_directories(char *, int);
 
 void update_statistics_full(char *fn, long total, long done, double time);
 void update_statistics_notime(char *fn, long total, long done, double time);
@@ -28,9 +28,9 @@ void start_encode_full(char *fn, char *outfn, int bitrate, float quality, int qs
 void start_encode_null(char *fn, char *outfn, int bitrate, float quality, int qset,
         int managed, int min, int max);
 void final_statistics(char *fn, double time, int rate, long total_samples,
-		long bytes);
+        long bytes);
 void final_statistics_null(char *fn, double time, int rate, long total_samples,
-		long bytes);
+        long bytes);
 void encode_error(char *errmsg);
 
 typedef struct {
@@ -40,88 +40,107 @@ typedef struct {
 
 typedef struct
 {
-	char **title;
-	int title_count;
-	char **artist;
-	int artist_count;
-	char **album;
-	int album_count;
-	char **comments;
-	int comment_count;
-	char **tracknum;
-	int track_count;
-	char **dates;
-	int date_count;
-	char **genre;
-	int genre_count;
+    char **title;
+    int title_count;
+    char **artist;
+    int artist_count;
+    char **album;
+    int album_count;
+    char **comments;
+    int comment_count;
+    char **tracknum;
+    int track_count;
+    char **dates;
+    int date_count;
+    char **genre;
+    int genre_count;
+    char **lyrics;
+    int lyrics_count;
+    char **lyrics_language;
+    int lyrics_language_count;
     adv_opt *advopt;
     int advopt_count;
-	int copy_comments;
 
-	int quiet;
+    int copy_comments;
+    int with_skeleton;
+    int quiet;
+    int rawmode;
 
-	int rawmode;
-	int raw_samplesize;
-	int raw_samplerate;
-	int raw_channels;
+    int raw_samplesize;
+    int raw_samplerate;
+    int raw_channels;
     int raw_endianness;
 
-	char *namefmt;
+    char *namefmt;
     char *namefmt_remove;
     char *namefmt_replace;
-	char *outfile;
 
-	/* All 3 in kbps */
+    char *outfile;
+
+    /* All 3 in kbps */
     int managed;
-	int min_bitrate;
-	int nominal_bitrate;
-	int max_bitrate;
+    int min_bitrate;
+    int nominal_bitrate;
+    int max_bitrate;
 
-	/* Float from 0 to 1 (low->high) */
-	float quality;
+    /* Float from 0 to 1 (low->high) */
+    float quality;
     int quality_set;
 
     int resamplefreq;
     int downmix;
     float scale;
 
-	unsigned int serial;
+    unsigned int serial;
+    unsigned int skeleton_serial;
+    unsigned int kate_serial;
+    int fixedserial;
+    int ignorelength;
+
+    int isutf8;
 } oe_options;
 
 typedef struct
 {
-	vorbis_comment *comments;
-	unsigned int serialno;
+    vorbis_comment *comments;
+    unsigned int serialno;
+    unsigned int skeleton_serialno;
+    unsigned int kate_serialno;
 
-	audio_read_func read_samples;
-	progress_func progress_update;
-	enc_end_func end_encode;
-	enc_start_func start_encode;
-	error_func error;
-	
-	void *readdata;
+    audio_read_func read_samples;
+    progress_func progress_update;
+    enc_end_func end_encode;
+    enc_start_func start_encode;
+    error_func error;
 
-	long total_samples_per_channel;
-	int channels;
-	long rate;
-	int samplesize;
+    void *readdata;
+
+    long total_samples_per_channel;
+    int channels;
+    long rate;
+    int samplesize;
     int endianness;
     int resamplefreq;
-	int copy_comments;
+    int copy_comments;
+    int with_skeleton;
 
-	/* Various bitrate/quality options */
+    /* Various bitrate/quality options */
     int managed;
-	int bitrate;
-	int min_bitrate;
-	int max_bitrate;
-	float quality;
+    int bitrate;
+    int min_bitrate;
+    int max_bitrate;
+    float quality;
     int quality_set;
     adv_opt *advopt;
     int advopt_count;
 
-	FILE *out;
-	char *filename;
-	char *infilename;
+    FILE *out;
+    char *filename;
+    char *infilename;
+    int ignorelength;
+
+    char *lyrics;
+    char *lyrics_language;
 } oe_enc_opt;
 
 
